@@ -2,7 +2,7 @@
 use strict;
 $|=1;
 
-# $Id: smokeperl.pl 902 2005-09-08 23:10:28Z abeltje $
+# $Id: smokeperl.pl 1042 2007-04-06 21:18:34Z abeltje $
 use vars qw( $VERSION );
 $VERSION = Test::Smoke->VERSION;
 
@@ -41,7 +41,7 @@ GetOptions( \%options,
     'archive!',
     'is56x',
     'defaultenv!',
-    'continue',
+    'continue!',
     'smartsmoke!',
     'snapshot|s=i',
     'killtime=s',
@@ -80,7 +80,7 @@ It can take these options
   --[no]ccp5p_onfail       Do (not) send failure reports to perl5-porters
   --[no]delay_report       Do (not) create the report now
 
-  --continue               Try to continue an interrupted smoke
+  --[no]continue           Try to continue an interrupted smoke
   --is56x                  This is a perl-5.6.x smoke
   --defaultenv             Run a smoke in the default environment
   --[no]smartsmoke         Don't smoke unless patchlevel changed
@@ -277,7 +277,7 @@ L<README>, L<FAQ>, L<configsmoke.pl>, L<mktest.pl>, L<mkovz.pl>
 
 =head1 REVISION
 
-$Id: smokeperl.pl 902 2005-09-08 23:10:28Z abeltje $
+$Id: smokeperl.pl 1042 2007-04-06 21:18:34Z abeltje $
 
 =head1 COPYRIGHT
 
