@@ -1,10 +1,12 @@
 package TestLib;
 use strict;
 
-# $Id: TestLib.pm 832 2005-02-12 19:52:03Z abeltje $
+# $Id: TestLib.pm 992 2006-06-04 08:52:09Z abeltje $
 use vars qw( $VERSION @EXPORT );
 $VERSION = '0.05';
 
+use Test::Smoke::Util qw( whereis );
+
 use base 'Exporter';
 @EXPORT = qw( 
     &whereis
@@ -40,76 +42,6 @@ use File::Spec::Functions qw( :DEFAULT abs2rel rel2abs
 require File::Path;
 use Cwd;
 
-=item whereis( $prog )
-
-Try to find an executable instance of C<$prog> in $ENV{PATH}.
-
-Rreturns a full file-path (with extension) to it.
-
-=cut
-
-sub whereis {
-    my $prog = shift;
-    return undef unless $prog; # you shouldn't call it '0'!
-    $^O eq 'VMS' and return vms_whereis( $prog );
-
-    my $p_sep = $Config::Config{path_sep};
-    my @path = split /\Q$p_sep\E/, $ENV{PATH};
-    my @pext = split /\Q$p_sep\E/, $ENV{PATHEXT} || '';
-    unshift @pext, '';
-
-    foreach my $dir ( @path ) {
-        foreach my $ext ( @pext ) {
-            my $fname = File::Spec->catfile( $dir, "$prog$ext" );
-            return $fname if -x $fname;
-        }
-    }
-    return '';
-}
-
-=item vms_whereis( $prog )
-
-First look in the SYMBOLS to see if C<$prog> is there.
-Next look in the KFE-table C<INSTALL LIST> if it is there.
-As a last resort we can scan C<DCL$PATH> like we do on *nix/Win32
-
-=cut
-
-sub vms_whereis {
-    my $prog = shift;
-
-    # Check SYMBOLS
-    eval { require VMS::DCLsym };
-    if ( $@ ) {
-        carp "Oops, cannot load VMS::DCLsym: $@";
-    } else {
-        my $syms = VMS::DCLsym->new;
-        return $prog if scalar $syms->getsym( $prog );
-    }
-    # Check Known File Entry table (INSTALL LIST)
-    my $img_re = '^\s+([\w\$]+);\d+';
-    my %kfe = map {
-        my $img = /$img_re/ ? $1 : '';
-        ( uc $img => undef )
-    } grep /$img_re/ => qx/INSTALL LIST/;
-    return $prog if exists $kfe{ uc $prog };
-
-    my $dclp_env = 'DCL$PATH';
-    my $p_sep = $Config{path_sep} || '|';
-    my @path = split /$p_sep/, $ENV{ $dclp_env }||"";
-    my @pext = ( $Config{exe_ext} || $Config{_exe}, '.COM' );
-
-    foreach my $dir ( @path ) {
-        foreach my $ext ( @pext ) {
-            my $fname = File::Spec->catfile( $dir, "$prog$ext" );
-            if ( -x $fname ) {
-                return $ext eq '.COM' ? "\@$fname" : "$fname";
-            }
-        }
-    }
-    return '';
-}
-
 =item manify_path( $path )
 
 Do a OS-specific split on the path, and join with '/' for MANIFEST
